# Copyright (C) 2023 Adam Lugowski.
# Use of this source code is governed by the BSD 2-clause license found in the LICENSE.txt file.
# SPDX-License-Identifier: BSD-2-Clause
"""
Import this module to automatically print pydata/sparse matrices using MatRepr.

A `__repr__` method that calls MatRepr is inserted to those classes.

Also includes all public methods from the matrepr module for convenient one-line imports.
"""

from .. import *

import sparse


def _str_(mat):
    from matrepr.adapters.sparse_driver import PyDataSparseDriver
    return to_str(PyDataSparseDriver.adapt(mat))


sparse.COO.__repr__ = _str_
sparse.DOK.__repr__ = _str_
sparse.GCXS.__repr__ = _str_



# Copyright (C) 2023 Adam Lugowski.
# Use of this source code is governed by the BSD 2-clause license found in the LICENSE.txt file.
# SPDX-License-Identifier: BSD-2-Clause

"""
Note: Only import this in Jupyter.
If not using Jupyter then just `import matrepr`.

Importing this module registers HTML formatters with Jupyter.

Also includes all public methods from the matrepr module for convenient one-line imports.
"""
from . import *
from . import _register_jupyter_formatter, _driver_registration_notify


def _repr_html_(mat):
    return to_html(mat, notebook=True)


def _register_html_formatters_with_jupyter(_=None):
    _register_jupyter_formatter("text/html", _repr_html_)


_register_html_formatters_with_jupyter()
_driver_registration_notify.append(_register_html_formatters_with_jupyter)



# Copyright (C) 2023 Adam Lugowski.
# Use of this source code is governed by the BSD 2-clause license found in the LICENSE.txt file.
# SPDX-License-Identifier: BSD-2-Clause
"""
Import this module to automatically print python-graphblas `Matrix` and `Vector` using MatRepr.

A `__repr__` method that calls MatRepr is inserted to those classes.

Also includes all public methods from the matrepr module for convenient one-line imports.
"""

from .. import *

import graphblas


def _str_(mat):
    return to_str(mat)


graphblas.Matrix.__repr__ = _str_
graphblas.Vector.__repr__ = _str_



# Copyright (C) 2023 Adam Lugowski.
# Use of this source code is governed by the BSD 2-clause license found in the LICENSE.txt file.
# SPDX-License-Identifier: BSD-2-Clause

"""
Note: Only import this in Jupyter.
If not using Jupyter then just `import matrepr`.

Importing this module registers formatters with Jupyter.

Also includes all public methods from the matrepr module for convenient one-line imports.
"""

# noinspection PyUnresolvedReferences
from .jupyter_html import *
